@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2017-11-13 - v1.003
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.051.
+
+=item *
+
 2017-06-12 - v1.002
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.050.
@@ -186,7 +192,7 @@ EIB EIE EIH EIL EIN EIS EIY EJA EJH EKA EKB EKD EKE EKI EKM EKN EKO EKT
 EKX EKY ELA ELB ELC ELD ELE ELF ELG ELH ELI ELJ ELK ELL ELM ELN ELO ELP
 ELQ ELR ELS ELT ELU ELV ELW ELX ELY ELZ EMA EMB EMD EME EMG EMI EMK EML
 EMM EMN EMO EMP EMS EMT EMX EMY ENA ENB ENC END ENE ENF ENH ENI ENJ ENK
-ENL ENN ENO ENQ ENS ENT ENU ENV ENW ENX ENY EOH EOI EOK EOR EOS EOZ EPG
+ENL ENN ENO ENQ ENS ENT ENU ENV ENW ENX ENY EOH EOI EOK EOR EOS EOZ EPA EPG
 EPH EPI EPK EPL EPN EPO EPR EPS EPT EPZ EQS EQY ERA ERB ERC ERD ERE ERF
 ERH ERI ERL ERM ERN ERO ERR ERS ERT ERU ERV ERZ ESA ESB ESC ESD ESE ESF
 ESG ESH ESI ESK ESL ESM ESN ESO ESP ESR ESS EST ESU ESW ESX ETB ETD ETE
@@ -562,7 +568,7 @@ VDM VDP VDS VDU VDZ VEE VEG VEJ VEL VER VEV VEX VEY VFA VGA VGD VGG VGO
 VGS VGT VGZ VHC VHM VHN VHY VHZ VIA VIB VIC VID VIE VIF VIG VIH VII VIJ
 VIK VIL VIN VIQ VIR VIS VIT VIU VIV VIX VIY VJB VJI VJQ VKG VKO VKS VKT
 VKW VLA VLC VLD VLE VLI VLK VLL VLM VLN VLO VLP VLR VLS VLU VLV VME VMI
-VMU VNA VNC VND VNE VNG VNO VNR VNS VNX VNY VOG VOH VOI VOK VOL VOT VOZ
+VMU VNA VNC VND VNE VNG VNO VNR VNS VNX VNY VOD VOG VOH VOI VOK VOL VOT VOZ
 VPC VPE VPN VPS VPY VPZ VQN VQQ VQS VRA VRB VRC VRE VRK VRL VRN VRS VRU VRX
 VRY VSA VSE VSF VSG VSO VST VTA VTB VTE VTF VTG VTL VTN VTU VTX VTZ VUO
 VUP VUS VUW VVB VVC VVI VVK VVO VVZ VXC VXE VXO VYD VYH VYS WAA WAB WAC
