@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2017-11-13 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.051.
+
+=item *
+
 2017-06-12 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.050.
@@ -170,7 +176,7 @@ EGUJ EGUL EGUM EGUN EGUO EGUP EGUU EGUW EGUY EGVA EGVC EGVE EGVF EGVG
 EGVH EGVI EGVJ EGVN EGVO EGVP EGVV EGVW EGWB EGWC EGWD EGWE EGWI EGWN
 EGWR EGWS EGWU EGWX EGWZ EGXA EGXC EGXD EGXE EGXF EGXG EGXH EGXJ EGXM
 EGXN EGXO EGXS EGXT EGXU EGXV EGXW EGXZ EGYB EGYC EGYD EGYE EGYH EGYM
-EGYP EGYW EGYY EHAA EHAM EHBK EHDB EHDL EHEH EHGG EHGR EHHV EHKD EHLE
+EGYP EGYW EGYY EHAA EHAM EHBK EHDB EHDL EHDR EHEH EHGG EHGR EHHV EHKD EHLE
 EHLW EHRD EHSB EHTE EHTW EHTX EHVB EHVK EHVL EHWO EIAB EIBN EIBR EIBT
 EICA EICB EICK EICM EICN EIDL EIDW EIFR EIGM EIGN EIHN EIIM EIIR EIKL
 EIKN EIKY EILT EIME EIMN EINN EIRT EISG EISP EITM EIWF EIWT EKAE EKAH
@@ -201,7 +207,7 @@ EYVA EYVC EYVI EYVK EYVL EYVN EYZA FAAB FAAN FABL FABM FABY FACL FACT
 FACV FADA FADN FAEL FAEO FAFF FAFR FAGB FAGE FAGG FAGM FAGR FAHS FAIR
 FAKM FALA FALE FALT FALW FALY FAMB FAME FAMG FAMM FAMO FANC FANS
 FAOB FAOH FAOR FAPB FAPE FAPH FAPI FAPJ FAPM FAPR FAQT FARB FASB FATC FATN
-FATZ FAUP FAUT FAVB FAVR FAVY FAWB FAWK FAWM FAWW FBCO FBFT FBGM FBGR
+FATZ FAUP FAUT FAVB FAVR FAVY FAWB FAWK FAWM FBCO FBFT FBGM FBGR
 FBGZ FBHQ FBJW FBKE FBKG FBKR FBKY FBLT FBMG FBMM FBMN FBMS FBNN FBNT
 FBOK FBOR FBPA FBPY FBRK FBSD FBSK FBSN FBSP FBSV FBSW FBTE FBTL FBTP
 FBTS FBXB FBXG FCBB FCBD FCBG FCBK FCBL FCBM FCBO FCBS FCBT FCBU FCBV
@@ -223,7 +229,7 @@ FSAL FSAS FSDA FSDR FSFA FSIA FSMA FSPL FSPP FSSA FSSB FSSC FSSD FSSF
 FSSR FTTA FTTC FTTD FTTJ FTTK FTTL FTTN FTTP FTTY FVBB FVBI FVBU FVCH
 FVCZ FVFA FVGO FVHA FVHC FVKA FVKB FVMT FVMV FVRU FVTL FVWN FWCL FWCT
 FWDZ FWKA FWKI FWKK FWMG FWMY FWMZ FWSM FWUU FXMM FXMU FYGF FYKT FYLZ
-FYRK FYRU FYSM FYWH FZAA FZAG FZAM FZAN FZBA FZBO FZCA FZCS FZEA FZFK
+FYRK FYRU FYSM FYWE FYWH FZAA FZAG FZAM FZAN FZBA FZBO FZCA FZCS FZEA FZFK
 FZGN FZIA FZMB FZNA FZNC FZOA FZQA FZQM FZRA FZRF FZRQ FZSA FZUA FZUH
 FZUK FZVA FZVI FZVS FZWA GABG GABS GAGO GAHB GAKA GAKL GAKO GAKT GAKY
 GAMB GAMK GANK GANR GASG GASK GASN GATB GATS GBYD GCFV GCGM GCHI GCLA
@@ -245,7 +251,7 @@ HSRN HSSJ HSSM HSSP HSSS HSSW HTAR HTBU HTDA HTDO HTIR HTKA HTKI HTKJ
 HTMB HTMG HTMO HTMS HTMT HTMU HTMW HTNA HTPE HTSE HTSO HTSY HTTB HTTG
 HTZA HUAR HUEN HUFP HUGU HUJI HUKB HUKS HULI HUMA HUMI HUMO HUSO HUTO
 HZHN KAAF KAAP KABE KABI KABL KABQ KABR KABX KABY KACB KACK KACT KACV
-KACY KADG KADM KADR KADS KADT KADW KAED KAEL KAET KAEX KAFF KAFN KAFO
+KACY KADG KADM KADR KADS KADT KADW KAED KAEG KAEL KAET KAEX KAFF KAFN KAFO
 KAFW KAGC KAGO KAGS KAHC KAHD KAHF KAHH KAHN KAHT KAIA KAIB KAID KAIK
 KAIN KAIO KAIV KAIY KAIZ KAKB KAKC KAKH KAKI KAKK KAKO KAKP KAKQ KAKR
 KALB KALE KALI KALM KALN KALO KALS KALW KALX KALZ KAMA KAMG KAMK KAMN
@@ -307,7 +313,7 @@ KGFL KGGB KGGE KGGG KGGW KGHM KGHW KGIF KGJT KGKT KGLD KGLE KGLH KGLQ
 KGLR KGLS KGLV KGLW KGMT KGMU KGMV KGNG KGNT KGNU KGNV KGOF KGOK KGOL
 KGON KGPT KGPZ KGQQ KGRB KGRD KGRE KGRF KGRI KGRK KGRM KGRN KGRR KGSB
 KGSH KGSO KGSP KGST KGTB KGTF KGTG KGTR KGTY KGUC KGUF KGUN KGUP KGUS
-KGUY KGVE KGVL KGVT KGVW KGWO KGWS KGWV KGXY KGYR KGYY KGZH KHAB KHAE
+KGUY KGVE KGVL KGVT KGVW KGWO KGWS KGWV KGXY KGYH KGYR KGYY KGZH KHAB KHAE
 KHAF KHAI KHAO KHAR KHAT KHAX KHAY KHBB KHBC KHBG KHBH KHBO KHBR KHCA
 KHCB KHCC KHCR KHCW KHDA KHDE KHDN KHDO KHED KHEE KHEI KHES KHEY KHEZ
 KHFD KHFF KHGR KHGT KHGX KHGZ KHHF KHHH KHHI KHHR KHIB KHIE KHIF KHII
@@ -586,7 +592,7 @@ SVTC SVTM SVTR SVUM SVVA SVVG SVVL SVVP SWBC SWPI SYGT SYTM TAPA TAPH
 TBPB TBPO TDCF TDPD TDPR TFFF TFFG TFFJ TFFR TGPY TIST TISX TJBQ TJCP
 TJFA TJFF TJIG TJMZ TJNR TJPS TJSJ TJVQ TKPK TKPN TLPC TLPL TNCA TNCB
 TNCC TNCE TNCM TNCS TQPF TRPM TTCP TTPP TTPT TUPJ TVSB TVSC TVSM TVSU
-TVSV TXKF UAAA UAAH UAAT UACC UADD UAFF UAFL UAFM UAFO UAFP UAII UAKK
+TVSV TXKF UAAA UAAH UAAT UACC UACP UADD UAFF UAFL UAFM UAFO UAFP UAII UAKK
 UAOO UARR UATA UATE UATG UATT UBBB UBTT UDSG UDYZ UEEE UELL UGKK UGKO
 UGKS UGMM UGSB UGSS UGTB UHBP UHHH UHHO UHMA UHMD UHMM UHMP UHPP UHSS
 UHWW UIAA UIII UIIO UIKB UIKK UINN UIUH UIUU UKBB UKBD UKCC UKCM UKCW
