@@ -25,10 +25,23 @@ This is a much shorter history than POP3's.
 
 Philippe "BooK" Bruhat.
 
-Introduced in Acme-MetaSyntactic version 0.68, published on April 3, 2006.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-04-03
+
+Introduced in Acme-MetaSyntactic version 0.68.
+
+=back
 
 =head1 SEE ALSO
 
