@@ -20,17 +20,34 @@ Over the hills and far away, Teletubbies come to play.
 
 Philippe "BooK" Bruhat.
 
-Introduced in Acme-MetaSyntactic version 0.23, published on May 23, 2005.
-
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
-
 =head1 ACKNOWLEDGMENT
-
+ 
 Thanks to Jrme Fenal, for inspiration over IRC.
 
-Updated with an C<=encoding> pod command in version 1.001,
-published on May 14,2012
+=head1 CHANGES
+
+=over 4
+
+=item *
+
+2012-05-14 - v1.001
+
+Updated with an C<=encoding> pod command
+in Acme-MetaSyntactic-Themes version 1.001.
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-05-23
+
+Introduced in Acme-MetaSyntactic version 0.23.
+
+=back
 
 =head1 SEE ALSO
 
